/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { HelpMenuE2EComponent } from 'apps/alfa-e2e/src/components/user-assistance/help-menu.component.e2e';
import { HeaderE2EComponent } from 'apps/alfa-e2e/src/page-objects/header.po';
import { MainPage, waitForSpinnerToDisappear } from 'apps/alfa-e2e/src/page-objects/main.po';
import { dropCollections } from 'apps/alfa-e2e/src/support/cypress-helper';
import { exist } from 'apps/alfa-e2e/src/support/cypress.util';
import { loginAsSabine } from 'apps/alfa-e2e/src/support/user-util';

describe('Help Menu', () => {
  const mainPage: MainPage = new MainPage();
  const header: HeaderE2EComponent = mainPage.getHeader();
  const helpMenu: HelpMenuE2EComponent = header.getHelpMenu();

  before(() => {
    loginAsSabine();

    waitForSpinnerToDisappear();
    exist(header.getRoot());
  });

  after(() => {
    dropCollections();
  });

  describe('open documentation', () => {
    it('should show "open documentation" button', () => {
      helpMenu.getRoot().click();

      exist(helpMenu.getOpenDocumentationButton());
    });

    it('should open file', () => {
      helpMenu
        .getOpenDocumentationButton()
        .find('a')
        .invoke('removeAttr', 'target')
        .click()
        .url()
        .should('include', 'benutzerleitfaden');
    });
  });
});
