/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { encodeUrlForEmbedding } from '@alfa-client/tech-shared';
import {
  VorgangAttachedItemClientE2E,
  VorgangAttachedItemE2E,
  VorgangAttachedItemNameE2E,
} from '../model/vorgang-attached-item';
import { WiedervorlageE2E } from '../model/wiedervorlage';
import { buildUrl } from './tech.util';
import { getUserSabineId } from './user-util';
import { VORGANG_ATTACHED_ITEM_CLASS } from './vorgang-attached-item-util';
import { createVorgangUriById } from './vorgang-util';

/** @deprecated */
const wiedervorlageFixture: WiedervorlageE2E = require('../fixtures/wiedervorlage/wiedervorlage.json');

/** @deprecated */
export function createWiedervorlage(): WiedervorlageE2E {
  return wiedervorlageFixture;
}

/** @deprecated */
export function buildWiedervorlage(_id: string, uiIdentifier: string): WiedervorlageE2E {
  return {
    ...wiedervorlageFixture,
    _id,
    betreff: uiIdentifier,
  };
}

export function createWiedervorlageNeuUriByVorgangId(id: string): string {
  return `${createVorgangUriById(id)}/wiedervorlage/neu`;
}

export function createWiedervorlageUriByVorgangIdAndWiedervorlageId(
  vorgangId: string,
  wiedervorlageId: string,
): string {
  return `${createVorgangUriById(vorgangId)}/wiedervorlage/${encodeUrlForEmbedding(buildUrl(wiedervorlageId, 'wiedervorlages'))}`;
}

const wiedervorlageItemFixture: WiedervorlageE2E = require('../fixtures/wiedervorlage/wiedervorlage.json');

//TODO rename to createWiedervorlage if deprecated function removed
export function createWiedervorlageItem(betreff: string): WiedervorlageE2E {
  return { ...wiedervorlageItemFixture, betreff, createdBy: getUserSabineId() };
}

export function createWiedervorlageAttachedItem(
  _id: string,
  vorgangId: string,
): VorgangAttachedItemE2E {
  return {
    _id: { $oid: _id },
    version: 0,
    vorgangId,
    client: VorgangAttachedItemClientE2E.ALFA,
    itemName: VorgangAttachedItemNameE2E.WIEDERVORLAGE,
    item: {
      ...createWiedervorlageItem('Wiedervorlage'),
      vorgangId,
    },
    deleted: false,
    _class: VORGANG_ATTACHED_ITEM_CLASS,
  };
}
