#!/bin/bash
#
# Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
# Ministerpräsidenten des Landes Schleswig-Holstein
# Staatskanzlei
# Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
#
# Lizenziert unter der EUPL, Version 1.2 oder - sobald
# diese von der Europäischen Kommission genehmigt wurden -
# Folgeversionen der EUPL ("Lizenz");
# Sie dürfen dieses Werk ausschließlich gemäß
# dieser Lizenz nutzen.
# Eine Kopie der Lizenz finden Sie hier:
#
# https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
#
# Sofern nicht durch anwendbare Rechtsvorschriften
# gefordert oder in schriftlicher Form vereinbart, wird
# die unter der Lizenz verbreitete Software "so wie sie
# ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
# ausdrücklich oder stillschweigend - verbreitet.
# Die sprachspezifischen Genehmigungen und Beschränkungen
# unter der Lizenz sind dem Lizenztext zu entnehmen.
#

export NO_COLOR=1

if [ $# -eq 0 ]; then
    >&2 echo "This script is for Jenkins Execution of E2E-Tests"
    >&2 echo "Example: ./run-tests.sh admin-e2e main-tests cypress.config.ts"
    exit 1
fi
APP_NAME="${1:-alfa-e2e}"
APP_VARIATION="${2:-main-tests}"
CONFIG_FILE="${3:-cypress.config.ts}"

if [ -z $APP_NAME ]; then echo "App Folder not set" && exit 1; fi
if [ -z $APP_VARIATION ]; then echo "Variation Name not set" && exit 1; fi
if [ -z $CONFIG_FILE ]; then echo "Config File not set" && exit 1; fi

SCRIPT_DIR="$(dirname "$0")"
BASE_PATH=${SCRIPT_DIR}/${APP_NAME}
SPEC_GROUP=${BASE_PATH}/src/e2e/${APP_VARIATION}
COMMAND="npx cypress run --project ${BASE_PATH} --spec ${SPEC_GROUP} --config-file ${CONFIG_FILE}"
REPORT_PATH=${BASE_PATH}/reports/${APP_VARIATION}

echo "Run E2E for ${APP_NAME} with command: '$COMMAND'"

rm -rf ${REPORT_PATH}

eval $COMMAND
TEST_RESULT=$?

if [ -d "${REPORT_PATH}" ]; then
  MOCHA_REPORT_PATH=${REPORT_PATH}/mochawesome-report/
  MOCHA_REPORT_JSONS=${MOCHA_REPORT_PATH}.jsons
  MOCHA_REPORT_FILE=${MOCHA_REPORT_PATH}report.json

  mv ${MOCHA_REPORT_JSONS} ${MOCHA_REPORT_PATH}/jsons
  npx mochawesome-merge ${MOCHA_REPORT_PATH}**/*.json > ${MOCHA_REPORT_FILE}
  # Workaround: mochawesome's "screenshotsFolder" value is not added in the generated HTML file. Add "screenshots" to image paths.
  sed --in-place --regexp-extended 's/"([^"]*\.png)/"screenshots\1/' ${MOCHA_REPORT_FILE}
  npx marge ${MOCHA_REPORT_FILE} -f report -o ${REPORT_PATH}
else
	echo "ERROR: Reports do not exist at ${REPORT_PATH}"
fi

exit $TEST_RESULT