/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { AdminOrganisationsEinheitListResource, OrganisationsEinheitContainerComponent } from '@admin-client/admin-settings';
import { StateResource, ToEmbeddedResourcesPipe, createStateResource } from '@alfa-client/tech-shared';
import { Mock, existsAsHtmlElement, getMockComponent, mock } from '@alfa-client/test-utils';
import { SpinnerComponent } from '@alfa-client/ui';
import { OrganisationsEinheitListResource } from '@alfa-client/zustaendige-stelle-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { getDataTestIdOf } from '../../../../../../tech-shared/test/data-test';
import { createAdminOrganisationsEinheitListResource } from '../../../../test/organisations-einheit/organisations-einheit';
import { OrganisationsEinheitService } from '../organisationseinheit.service';
import { OrganisationsEinheitListComponent } from './organisationseinheit-list/organisationseinheit-list.component';

describe('OrganisationsEinheitContainerComponent', () => {
  let component: OrganisationsEinheitContainerComponent;
  let fixture: ComponentFixture<OrganisationsEinheitContainerComponent>;
  let organisationsEinheitService: Mock<OrganisationsEinheitService>;

  const organisationsEinheitListStateResource: StateResource<AdminOrganisationsEinheitListResource> = createStateResource(
    createAdminOrganisationsEinheitListResource(),
  );

  const listSelector: string = getDataTestIdOf('organisations-einheit-list');

  beforeEach(async () => {
    organisationsEinheitService = {
      ...mock(OrganisationsEinheitService),
      getList: jest.fn().mockReturnValue(of(organisationsEinheitListStateResource)),
    };

    await TestBed.configureTestingModule({
      declarations: [
        OrganisationsEinheitContainerComponent,
        MockComponent(OrganisationsEinheitListComponent),
        MockComponent(SpinnerComponent),
        ToEmbeddedResourcesPipe,
      ],
      imports: [ButtonWithSpinnerComponent],
      providers: [{ provide: OrganisationsEinheitService, useValue: organisationsEinheitService }],
    }).compileComponents();

    fixture = TestBed.createComponent(OrganisationsEinheitContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('component', () => {
    describe('ngOnInit', () => {
      it('should call organisationsEinheitService getList', (done) => {
        component.ngOnInit();

        component.organisationsEinheitListStateResource$.subscribe(() => {
          expect(organisationsEinheitService.getList).toHaveBeenCalled();
          done();
        });
      });

      it('should set organisationsEinheitListStateResource$', (done) => {
        component.ngOnInit();

        component.organisationsEinheitListStateResource$.subscribe(
          (listStateResource: StateResource<OrganisationsEinheitListResource>) => {
            expect(listStateResource).toBe(organisationsEinheitListStateResource);
            done();
          },
        );
      });
    });
  });

  describe('template', () => {
    describe('organisationsEinheiten list', () => {
      it('should show list', () => {
        existsAsHtmlElement(fixture, listSelector);
      });

      it('should have organisationsEinheitResources', () => {
        const listComponent: OrganisationsEinheitListComponent = getMockComponent(fixture, OrganisationsEinheitListComponent);
        expect(listComponent.organisationsEinheitResources).toBeTruthy();
      });
    });
  });
});
