/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidLinkRel, BescheidService } from '@alfa-client/bescheid-shared';
import { HasLinkPipe } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, mock, notExistsAsHtmlElement, triggerEvent, useFromMock } from '@alfa-client/test-utils';
import { DateEditorComponent } from '@alfa-client/ui';
import { VorgangWithEingangLinkRel } from '@alfa-client/vorgang-shared';
import { EventEmitter } from '@angular/core';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ReactiveFormsModule, UntypedFormBuilder } from '@angular/forms';
import { CloseIconComponent, RadioButtonCardComponent, StampIconComponent } from '@ods/system';
import { MockComponent } from 'ng-mocks';
import { createBescheidResource } from '../../../../../../../bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from '../../../../../../../tech-shared/test/data-test';
import { createVorgangWithEingangResource } from '../../../../../../../vorgang-shared/test/vorgang';
import { BescheidFormService } from '../../../bescheid.formservice';
import { BescheidWizardWeiterButtonComponent } from '../../weiter-button/bescheid-wizard-weiter-button.component';
import { BescheidWizardAntragBescheidenFormComponent } from './bescheid-wizard-antrag-bescheiden-form.component';

describe('BescheidWizardAntragBescheidenFormComponent', () => {
  let component: BescheidWizardAntragBescheidenFormComponent;
  let fixture: ComponentFixture<BescheidWizardAntragBescheidenFormComponent>;

  const weiterButton: string = getDataTestIdOf('weiter-button');

  let formService: BescheidFormService;

  beforeEach(async () => {
    formService = new BescheidFormService(new UntypedFormBuilder(), useFromMock(mock(BescheidService)));

    await TestBed.configureTestingModule({
      declarations: [
        BescheidWizardAntragBescheidenFormComponent,
        HasLinkPipe,
        MockComponent(BescheidWizardWeiterButtonComponent),
        MockComponent(RadioButtonCardComponent),
        MockComponent(StampIconComponent),
        MockComponent(CloseIconComponent),
        MockComponent(DateEditorComponent),
      ],
      providers: [
        {
          provide: BescheidFormService,
          useValue: formService,
        },
      ],
      imports: [ReactiveFormsModule],
    }).compileComponents();

    fixture = TestBed.createComponent(BescheidWizardAntragBescheidenFormComponent);
    component = fixture.componentInstance;
    component.weiterClickEmitter = useFromMock(mock(EventEmitter<void>));
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('alfa-bescheid-wizard-weiter-button', () => {
      it('should exists if bescheid update link exists', () => {
        component.bescheidResource = createBescheidResource([BescheidLinkRel.UPDATE]);

        fixture.detectChanges();

        existsAsHtmlElement(fixture, weiterButton);
      });

      it('should exists if create link exists', () => {
        component.vorgangWithEingangResource = createVorgangWithEingangResource([
          VorgangWithEingangLinkRel.CREATE_BESCHEID_DRAFT,
        ]);

        fixture.detectChanges();

        existsAsHtmlElement(fixture, weiterButton);
      });

      it('should not exists if update and create links missing', () => {
        component.vorgangWithEingangResource = createVorgangWithEingangResource();
        component.bescheidResource = createBescheidResource();

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, weiterButton);
      });

      it('should not exists if update link missing', () => {
        component.bescheidResource = createBescheidResource();

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, weiterButton);
      });

      describe('output', () => {
        it('should emit weiterClickEmitter', () => {
          component.bescheidResource = createBescheidResource([BescheidLinkRel.UPDATE]);

          fixture.detectChanges();

          triggerEvent({
            fixture,
            name: 'clickEmitter',
            elementSelector: weiterButton,
          });

          expect(component.weiterClickEmitter.emit).toHaveBeenCalled();
        });
      });
    });
  });
});
