/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  ApiError,
  createEmptyStateResource,
  createErrorStateResource,
  createStateResource,
} from '@alfa-client/tech-shared';
import { HttpErrorResponse } from '@angular/common/http';
import { Action } from '@ngrx/store';
import { Resource, ResourceUri } from '@ngxp/rest';
import { createApiError, createHttpErrorResponse } from '../../../../tech-shared/test/error';
import { createDummyResource } from '../../../../tech-shared/test/resource';
import { createCommandResource, createCreateCommand } from '../../../test/command';
import { CommandResource, CreateCommand } from '../command.model';
import { CommandState, initialState, reducer } from './command.reducer';

import { faker } from '@faker-js/faker';

import * as CommandActions from '../+state/command.actions';

describe('Command Reducer', () => {
  describe('unknown action', () => {
    it('should return current state', () => {
      const action: Action = {} as Action;

      const result: any = reducer(initialState, action);

      expect(result).toBe(initialState);
    });
  });

  describe('createCommand', () => {
    const resource: Resource = createDummyResource();
    const linkRel: ResourceUri = faker.internet.url();
    const command: CreateCommand = createCreateCommand();

    it('should create empty loading map entry', () => {
      const action = CommandActions.createCommand({ resource, linkRel, command });

      const state: CommandState = reducer(initialState, action);

      expect(state.commandByOrderMap[command.order]).toEqual(createEmptyStateResource(true));
    });
  });

  describe('createCommandSuccess', () => {
    const command: CommandResource = createCommandResource();

    it('should create stateResource entry by loaded resource', () => {
      const action = CommandActions.createCommandSuccess({ command });

      const state: CommandState = reducer(initialState, action);

      expect(state.commandByOrderMap[command.order]).toEqual(createStateResource(command));
    });
  });

  describe('createCommandFailure', () => {
    const command: CommandResource = createCommandResource();
    const error: ApiError = createApiError();
    const httpErrorResponse: HttpErrorResponse = { ...createHttpErrorResponse(), error };

    it('should create errorStateResource entry by occured error', () => {
      const action = CommandActions.createCommandFailure({ command, error: httpErrorResponse });

      const state: CommandState = reducer(initialState, action);

      expect(state.commandByOrderMap[command.order]).toEqual(createErrorStateResource(error));
    });
  });
});
