/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  EMPTY_STRING,
  ResourceRepository,
  ResourceService,
  ResourceServiceConfig,
  StateResource,
  createEmptyStateResource,
} from '@alfa-client/tech-shared';
import { Resource } from '@ngxp/rest';
import { BehaviorSubject, Observable } from 'rxjs';
import { CommandResource, CreateCommandProps } from './command.model';
import { CommandService } from './command.service';

export class CommandResourceService<B extends Resource, T extends Resource> extends ResourceService<B, T> {
  deleteStateCommandResource: BehaviorSubject<StateResource<CommandResource>> = new BehaviorSubject<
    StateResource<CommandResource>
  >(createEmptyStateResource());

  constructor(
    protected config: ResourceServiceConfig<B>,
    protected repository: ResourceRepository,
    private commandService: CommandService,
  ) {
    super(config, repository);
  }

  doSave(resource: T, toSave: unknown): Observable<T> {
    throw new Error('Method not implemented.');
  }

  doPatch(resource: T, toPatch: unknown): Observable<T> {
    throw new Error('Method not implemented.');
  }

  public delete(): Observable<StateResource<CommandResource>> {
    return this.commandService.createCommandByProps(this.buildDeleteCommandProps());
  }

  private buildDeleteCommandProps(): CreateCommandProps {
    return {
      resource: this.stateResource.value.resource,
      linkRel: this.config.delete.linkRel,
      command: { order: this.config.delete.order, body: null },
      snackBarMessage: EMPTY_STRING,
    };
  }
}
