/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Injectable } from '@angular/core';
import { VorgangService } from '@alfa-client/vorgang-shared';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import { concatLatestFrom } from '@ngrx/operators';
import { of } from 'rxjs';
import { catchError, map, switchMap } from 'rxjs/operators';
import { HistorieService } from './historie.service';

import * as HistorieActions from './historie.actions';

@Injectable()
export class HistorieEffects {
  constructor(
    private readonly actions$: Actions,
    private service: HistorieService,
    private vorgangService: VorgangService,
  ) {}

  loadAll = createEffect(() =>
    this.actions$.pipe(
      ofType(HistorieActions.loadHistorie),
      concatLatestFrom(() => this.vorgangService.getVorgangWithEingang()),
      switchMap(([, vorgang]) => {
        return this.service.loadAll(vorgang.resource).pipe(
          map((historieList) => HistorieActions.loadHistorieSuccess({ historieList })),
          catchError((apiError) => of(HistorieActions.loadHistorieFailed({ apiError }))),
        );
      }),
    ),
  );
}
