/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createInvalidParam, createProblemDetail } from '../../../test/error';
import { InvalidParam, ProblemDetail } from '../tech.model';
import { ValidationMessageCode } from '../validation/tech.validation.messages';
import * as TechValidationUtil from '../validation/tech.validation.util';
import { ConvertProblemDetailToErrorMessagesPipe } from './convert-problem-detail-to-error-messages.pipe';

describe('convertProblemDetailToErrorMessages', () => {
  const pipe = new ConvertProblemDetailToErrorMessagesPipe();

  it('create an instance', () => {
    expect(pipe).toBeTruthy();
  });

  describe('transform', () => {
    const getMessageForInvalidParam = jest.spyOn(TechValidationUtil, 'getMessageForInvalidParam');

    it('should not call getMessageForInvalidParam', () => {
      pipe.transform(null);

      expect(getMessageForInvalidParam).not.toHaveBeenCalled();
    });

    it('should call getMessageForInvalidParam', () => {
      pipe.transform(createProblemDetail());

      expect(getMessageForInvalidParam).toHaveBeenCalled();
    });

    it('should return array of error messages', () => {
      const expectedErrorMessage = 'Bitte  ausfüllen';
      const invalidParam: InvalidParam = {
        ...createInvalidParam(),
        reason: ValidationMessageCode.FIELD_EMPTY,
      };
      const problemDetail: ProblemDetail = createProblemDetail([invalidParam]);

      const errorMessages: string[] = pipe.transform(problemDetail);

      expect(errorMessages).toEqual([expectedErrorMessage]);
    });
  });
});
