/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Resource } from '@ngxp/rest';
import { createDummyResource } from 'libs/tech-shared/test/resource';
import { HasAnyLinkPipe } from './has-any-link.pipe';

import * as TechUtil from '../tech.util';

describe('HasAnyLinkPipe', () => {
  const oneLink: string = 'one';
  const anotherLink: string = 'another';
  const resource: Resource = createDummyResource([oneLink, anotherLink]);
  const pipe: HasAnyLinkPipe = new HasAnyLinkPipe();

  describe('transform', () => {
    let hasAnyLinkSpy: jest.SpyInstance<boolean>;

    beforeEach(() => {
      hasAnyLinkSpy = jest.spyOn(TechUtil, 'hasAnyLink').mockReturnValue(true);
    });

    it('should call has any link', () => {
      pipe.transform(resource, oneLink);

      expect(hasAnyLinkSpy).toHaveBeenCalledWith(resource, oneLink);
    });

    it('should return value', () => {
      const result: boolean = pipe.transform(resource, oneLink, anotherLink);

      expect(result).toBe(true);
    });
  });
});
