/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidService } from '@alfa-client/bescheid-shared';
import { CommandResource, tapOnCommandSuccessfullyDone } from '@alfa-client/command-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { OzgcloudDialogService } from '@alfa-client/ui';
import { Component } from '@angular/core';
import { Observable } from 'rxjs';
import { BescheidenFormService } from '../../../bescheiden.formservice';

@Component({
  selector: 'alfa-vorgang-detail-bescheiden-abbrechen-dialog',
  templateUrl: './vorgang-detail-bescheiden-abbrechen-dialog.component.html',
})
export class VorgangDetailBescheidenAbbrechenDialogComponent {
  saveDraftInProgress$: Observable<StateResource<CommandResource>>;
  deleteBescheid$: Observable<StateResource<CommandResource>>;

  constructor(
    private readonly bescheidService: BescheidService,
    private readonly ozgcloudDialogService: OzgcloudDialogService,
    private readonly formService: BescheidenFormService,
  ) {}

  public saveBescheidDraft() {
    this.saveDraftInProgress$ = this.formService.submitDraft().pipe(
      tapOnCommandSuccessfullyDone(() => {
        this.ozgcloudDialogService.closeAll();
        this.bescheidService.refreshList();
      }),
    );
  }

  public onCancel() {
    if (this.bescheidService.existsBescheidDraft()) {
      this.deleteBescheidDraft();
    } else {
      this.ozgcloudDialogService.closeAll();
    }
  }

  deleteBescheidDraft(): void {
    this.deleteBescheid$ = this.bescheidService.bescheidVerwerfen().pipe(
      tapOnCommandSuccessfullyDone(() => {
        this.ozgcloudDialogService.closeAll();
      }),
    );
  }
}
