/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { getElementFromFixture } from '@alfa-client/test-utils';
import { ScrollingModule } from '@angular/cdk/scrolling';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { getDataTestClassOf } from 'libs/tech-shared/test/data-test';
import { createVorgang } from '../../../../../../../vorgang-shared/test/vorgang';
import { VorgangBescheidStatusComponent } from './vorgang-bescheid-status.component';

describe('VorgangListComponent', () => {
  let component: VorgangBescheidStatusComponent;
  let fixture: ComponentFixture<VorgangBescheidStatusComponent>;

  const abgelehntElement: string = getDataTestClassOf('vorgang-abgelehnt');
  const bewilligtElement: string = getDataTestClassOf('vorgang-bewilligt');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [ScrollingModule],
      declarations: [VorgangBescheidStatusComponent],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(VorgangBescheidStatusComponent);
    component = fixture.componentInstance;
    component.vorgang = createVorgang();
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('render', () => {
    it('should render bewilligt', () => {
      component.vorgang.antragBewilligt = true;
      fixture.detectChanges();

      const element = getElementFromFixture(fixture, bewilligtElement);

      expect(element.innerHTML).toEqual('bewilligt');
    });

    it('should render abgelehnt', () => {
      component.vorgang.antragBewilligt = false;
      fixture.detectChanges();

      const element = getElementFromFixture(fixture, abgelehntElement);

      expect(element.innerHTML).toEqual('abgelehnt');
    });

    it('should not render', () => {
      component.vorgang.antragBewilligt = null;
      fixture.detectChanges();

      const element = getElementFromFixture(fixture, 'p');

      expect(element).not.toBeInstanceOf(HTMLElement);
    });
  });
});
