/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.wiedervorlage;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import de.ozgcloud.alfa.common.binaryfile.BinaryFileController;
import de.ozgcloud.alfa.common.file.OzgFile;
import de.ozgcloud.alfa.common.user.CurrentUserService;

@RestController
@RequestMapping(WiedervorlageController.WIEDERVORLAGE_PATH)
public class WiedervorlageController {

	static final String WIEDERVORLAGE_PATH = "/api/wiedervorlages"; // NOSONAR
	static final String PARAM_VORGANG_ID = "vorgangId";

	@Autowired
	private WiedervorlageService service;
	@Autowired
	private WiedervorlageModelAssembler modelAssembler;

	@PreAuthorize(CurrentUserService.VERIFY_HAS_ROLE_VERWALTUNG_USER)
	@GetMapping("/{wiedervorlageId}")
	public EntityModel<Wiedervorlage> getById(@PathVariable String wiedervorlageId) {
		return modelAssembler.toModel(service.getById(wiedervorlageId));
	}

	@GetMapping(params = PARAM_VORGANG_ID)
	public CollectionModel<EntityModel<Wiedervorlage>> findByVorgang(@RequestParam String vorgangId) {
		return modelAssembler.toCollectionModel(service.findByVorgangId(vorgangId), vorgangId);
	}

	@RestController
	@RequestMapping(AttachmentsByWiedervorlageController.PATH)
	static class AttachmentsByWiedervorlageController {

		static final String PATH = "/api/wiedervorlages/{wiedervorlageId}"; // NOSONAR

		@Autowired
		private BinaryFileController binaryFileController;
		@Autowired
		private WiedervorlageService service;

		@GetMapping("/attachments")
		public CollectionModel<EntityModel<OzgFile>> getAttachments(@PathVariable String wiedervorlageId) {
			var wiedervorlage = service.getById(wiedervorlageId);

			return binaryFileController.getFiles(wiedervorlage.getAttachments());
		}
	}
}