/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.bescheid;

import java.util.List;

import de.ozgcloud.bescheid.GrpcBescheid;
import de.ozgcloud.bescheid.GrpcSentInfo;
import de.ozgcloud.common.datatype.StringBasedValue;

public class GrpcBescheidTestFactory {

	public static final String ID = BescheidTestFactory.ID;
	public static final boolean BEWILLIGT = BescheidTestFactory.BEWILLIGT;
	public static final String BESCHIEDEN_AM = BescheidTestFactory.BESCHIEDEN_AM;
	public static final String BESCHEID_DOCUMENT = BescheidTestFactory.BESCHEID_DOCUMENT;
	public static final List<String> ATTACHMENTS = BescheidTestFactory.ATTACHMENTS.stream().map(StringBasedValue::toString).toList();
	public static final String NACHRICHT_TEXT = BescheidTestFactory.NACHRICHT_TEXT;
	public static final String NACHRICHT_SUBJECT = BescheidTestFactory.NACHRICHT_SUBJECT;
	public static final GrpcSentInfo SENT_INFO = GrpcSentInfoTestFactory.create();

	public static GrpcBescheid create() {
		return createBuilder().build();
	}

	public static GrpcBescheid.Builder createBuilder() {
		return GrpcBescheid.newBuilder()
				.setId(ID)
				.setStatus(BescheidTestFactory.STATUS.toString())
				.setBewilligt(BEWILLIGT)
				.setBeschiedenAm(BESCHIEDEN_AM)
				.setBescheidDocument(BESCHEID_DOCUMENT)
				.addAllAttachments(ATTACHMENTS)
				.setNachrichtText(NACHRICHT_TEXT)
				.setNachrichtSubject(NACHRICHT_SUBJECT)
				.setSendBy(BescheidTestFactory.SEND_BY.toString())
				.setSentInfo(SENT_INFO);
	}
}
